Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CollisionMessageParts ¶
type CollisionMessageParts struct {
Prefix string // "You were hit by "
VulnID string // The vulnerability ID (may contain hyperlink)
Suffix string // " (High, CVSS 7.5). Game over!"
}
CollisionMessageParts contains the parts of the collision message for proper rendering
func FormatCollisionMessageParts ¶
func FormatCollisionMessageParts(obs *obstacle) CollisionMessageParts
FormatCollisionMessageParts splits the collision message into parts for proper rendering
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model represents the main game state and handles all game logic for the Scanfrog terminal game.
func NewModel ¶
func NewModel(vulnSource grype.VulnerabilitySource) *Model
NewModel creates a new game model with the specified vulnerability source.
func (Model) Init ¶
Init initializes the game model and returns commands to load vulnerabilities and set up the terminal.
Click to show internal directories.
Click to hide internal directories.